@@ -9,22 +9,17 @@ Authors:
 * Alexander Belchenko (e-mail: bialix AT ukr.net)
 """
 
-#-----------------------------------------------------------------------------
-#  Copyright (C) 2008-2011  The IPython Development Team
-#
-#  Distributed under the terms of the BSD License.  The full license is in
-#  the file COPYING, distributed as part of this software.
-#-----------------------------------------------------------------------------
-
-#-----------------------------------------------------------------------------
-# Imports
-#-----------------------------------------------------------------------------
+# Copyright (c) IPython Development Team.
+# Distributed under the terms of the Modified BSD License.
 
 import os
-import struct
 import sys
 import warnings
-import shutil
+try:
+    from shutil import get_terminal_size as _get_terminal_size
+except ImportError:
+    # use backport on Python 2
+    from shutil import get_terminal_size as _get_terminal_size
 
 from . import py3compat
 
@@ -122,4 +117,4 @@ def freeze_term_title():
 
 
 def get_terminal_size(defaultx=80, defaulty=25):
-    return shutil.get_terminal_size((defaultx, defaulty))
+    return _get_terminal_size((defaultx, defaulty))
